
# q-expansion of newform 6018.2.a.x, downloaded from the LMFDB on 26 April 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 6018
weight = 2
poly_data = [272, -896, 416, 1176, -1032, -276, 341, 30, -34, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-66416, -399092, 300692, 67732, 12263, 32040, -5750, -4779, 225, 158], 120304], [[-1593080, 843124, 2975172, -1375194, -987205, 375768, 105416, -35705, -3275, 1042], 120304], [[-4079568, 6322324, 6020464, -7953632, -1593723, 2223525, 177972, -207243, -5918, 5903], 120304], [[-4432912, 8148160, 4205884, -11927502, 26618, 3954805, 21556, -393074, -1955, 11493], 60152], [[10265344, -18090136, -12453916, 26641132, 1739438, -8588857, -255106, 848932, 10767, -24821], 120304], [[-7071528, 14231612, 7212112, -21305118, -52371, 7121451, 62998, -711529, -4492, 20873], 60152], [[26070664, -51134312, -27434996, 76622382, 470848, -25415913, -221448, 2527192, 15269, -73925], 120304], [[-30442128, 62114404, 30417112, -92137756, 289317, 30729695, 197524, -3064731, -16752, 89793], 120304]]

hecke_ring_character_values = None
aps_data = [[-1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, -1, 0, 0], [0, -1, 0, 0, -1, -1, 0, -1, 0, 1], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [2, -1, 0, 0, -1, 0, 0, 0, 0, 0], [2, 0, 0, 1, 0, 1, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, -1, 1, 1], [1, -1, -1, -1, -1, -1, 0, -1, -1, 1], [0, -1, 1, 0, 1, 0, 1, 0, 0, 0], [0, -1, 1, 0, 0, 0, 1, 1, 0, 0], [3, 0, -1, 0, 0, 0, 1, 0, 0, -1], [1, 1, 0, 0, 0, -1, -1, 0, 0, 0], [0, 0, -1, -1, 0, 0, 0, 0, 0, -1], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 1, 0, 0, 0, 0, 0], [1, 1, 2, 0, 1, 0, 1, 0, 0, 1], [1, 2, -1, -1, 1, 1, 1, 1, -1, -1], [4, 1, -2, 0, -1, 0, -2, -1, 0, 0], [0, 2, 1, 1, 2, 1, 0, 2, 1, 0], [0, -1, -2, 0, -2, -1, 0, -1, 0, 1], [-3, 0, -2, 0, 0, 0, -1, -2, 0, 1], [3, 0, 2, 0, 1, 1, -1, -1, 0, 0], [-1, 0, 2, -1, -1, 0, -1, -1, 1, 0], [4, -2, 0, 3, 1, 0, 1, 0, 0, 1], [2, 0, 2, 3, 2, 1, 2, 2, 3, 0], [-2, -1, 1, -1, 1, 0, 2, 1, -1, 1], [-2, 0, -3, 1, 1, 2, 0, 1, -1, -1], [4, 1, -3, 0, -1, 0, -2, -2, -2, 0], [1, 1, 1, 0, 1, -1, 0, 1, 0, 0], [-1, -1, -2, 0, -2, -1, -1, 0, -2, 0], [3, 2, -1, 1, 1, -1, 0, 2, -1, -1], [2, 0, -4, 0, -1, -1, 0, 0, -2, -1], [3, -2, -1, 2, -1, 0, -1, -1, 1, -1], [0, 0, 1, 1, -1, -1, 2, 2, 2, 0], [0, 2, 0, 1, 1, 1, 1, 0, -1, -2], [2, -1, 3, -1, 1, 2, 2, 3, 1, 1], [0, -2, 0, 1, 0, -2, -1, 0, 1, -1], [-2, -3, 1, 3, 2, 0, 2, 0, 3, 3], [-2, -1, 0, 2, 2, 0, 1, 1, 2, 0], [-1, 0, 2, -1, -1, 0, 1, 3, -1, -2], [-1, 0, 1, -1, 0, 0, 4, 1, -1, 0], [-3, 1, -3, 1, 0, 0, -2, -3, -1, -2], [-1, -1, 0, -1, 0, -2, -1, -2, 0, 0], [-2, -1, 0, 3, 0, 0, -2, -1, -1, 1], [5, 0, -1, -1, -2, 0, -2, -1, -3, 0], [-5, 3, -2, -4, 0, -3, -1, 0, -2, 0], [6, 0, 2, 1, 0, 1, 3, 4, 0, 0], [5, 0, 0, 2, 1, 2, 2, 1, 0, -1], [-2, 0, -3, -3, -1, 0, -1, 0, -3, -1], [2, 2, -1, -5, 1, 0, 0, 2, -1, -1], [4, 0, 4, 1, 3, 3, 1, 3, 1, 0], [-2, -2, 4, 1, 2, -2, 1, 3, 3, 3], [8, -1, 2, 3, 1, 0, 0, 0, 4, 1], [-1, -3, 2, 1, 0, 2, -1, -2, 0, 0], [5, 3, -4, -3, -2, -1, 0, -1, -1, 1], [5, -1, 1, 2, 1, 2, 3, 3, -1, -1], [-4, 1, -1, 0, 4, 1, 0, 4, 2, -1], [0, 0, 3, 2, 0, 2, 0, -3, -2, 2], [-2, 3, -4, -2, -1, 1, 0, -1, -2, -1], [5, 1, 2, 1, 1, -1, -1, 1, 1, -1], [0, 1, -2, 0, -3, -3, 0, -2, 0, -1], [3, -1, 2, 3, 1, 2, 0, 3, 1, -2], [-1, -4, 6, 2, 2, 3, 1, 2, 2, 0], [2, -2, 4, 4, -3, 0, -1, -2, 2, 4], [11, 3, -5, -4, 3, 2, -1, 3, 0, -3], [8, 0, -2, -1, 1, 3, -5, -2, -1, -2], [-3, 0, 2, -2, 1, 1, -2, 3, -3, -4], [14, -2, 1, 1, 1, -1, 1, 2, 1, -2], [4, 8, -2, -9, 1, 0, -1, 2, -2, -3], [13, 0, 1, 0, 2, 2, 0, 4, 0, -3], [8, 1, 0, 2, -2, 2, -1, 0, 0, 2], [4, 2, 2, -2, -1, 1, 2, 2, 0, -1], [-3, 3, -6, -4, -2, -2, -1, 1, -7, -3], [-1, -3, 6, -2, 1, 0, 2, 3, 0, -1], [1, 3, -4, -2, -2, -3, -4, -4, -4, 0], [-4, -1, 4, 2, 0, -2, 5, 3, 4, 2], [5, -4, 0, 4, -1, -2, 0, -2, 2, 1], [-3, 1, -3, -2, -1, -5, 0, 0, -2, -2], [10, -1, 2, 4, -2, 1, 1, 1, 1, 3], [9, -2, 1, 2, 2, 3, 2, 1, 1, -2], [6, -1, -2, 3, 1, -2, 1, -3, -1, 3], [6, 1, -1, -4, -3, 0, -2, 1, -2, 0], [5, -2, 1, 4, 2, -1, 4, 3, 2, 2], [-2, 0, 4, 2, 4, 3, 1, -1, 4, -1], [11, 0, 6, 1, 3, 2, 1, 3, 1, 0], [3, -2, -1, -1, 2, 1, 0, 4, -2, -1], [6, -3, 6, 2, 0, 0, 2, -1, 0, 0], [3, 3, -1, -3, 4, 2, 1, 8, 1, -6], [1, 0, 2, 0, 3, -2, -1, 0, 0, 1], [4, 4, 2, -6, -1, 0, 1, 5, -1, -2], [1, -3, 1, 2, -1, 3, -4, 0, 2, 2], [6, 3, 3, 0, 2, -3, 2, -2, 2, 3], [7, -2, 4, 4, 1, 3, -1, 1, -1, -2], [-3, -7, 4, 5, 4, 3, 4, 3, 3, 3], [2, 5, -7, -7, -3, -3, -2, 0, -3, 0], [11, 4, 3, -2, 0, -2, 1, 2, 2, -1], [-2, 0, -2, -4, -2, -4, -1, 2, -4, -2], [8, -2, 5, 10, 0, 1, -3, -4, 4, 3], [12, 0, 3, 1, 4, 1, 1, 2, 5, 4], [-8, 1, -2, -3, -3, -6, -1, -5, -1, 5], [2, -2, -7, 0, 1, 1, 0, -1, -4, -5], [3, 0, 5, 1, 2, -1, 3, 6, -1, 1], [12, -2, 2, -4, 1, 1, 0, -1, 0, 3], [2, -6, 4, 3, 1, 2, 6, 5, 3, 1], [2, -8, 5, 0, -1, -2, 3, 2, -2, 2], [7, -1, 7, 4, 5, 4, 2, 3, 5, 1], [0, 7, 1, -5, -2, -2, 2, 0, -3, 1], [14, 3, 1, -1, 1, -1, 4, 0, 2, 0], [-1, -5, -1, 3, 0, -1, -1, -4, 0, 1], [-1, 5, -3, -2, -3, -4, -5, -5, -2, 1], [-4, -5, 7, 8, 1, 2, -2, 0, 6, 2], [11, -4, 1, 4, 1, 3, 3, 2, 2, -2], [-3, 1, -2, -2, -2, 0, -6, -5, -2, -1], [2, -3, 4, 0, 2, 0, 3, 2, 6, 2], [9, -4, 3, -1, 1, 2, -2, -4, 2, 0], [-3, 7, -2, -3, -1, 0, -3, -1, -3, -6], [7, 1, -4, 2, 0, 0, 4, -1, -2, 3], [1, 5, -6, -3, 0, -1, -2, -1, -3, -1], [0, 3, 6, 3, 4, 3, 3, 8, 5, -2], [11, -1, -6, -6, 1, 0, -2, 2, 0, -3], [-11, 1, -3, -4, -5, -5, -6, -9, -2, 4], [7, -4, 0, -1, 3, 5, 0, 2, -1, 1], [7, -3, 8, 5, 2, 5, 2, 3, 5, -1], [0, 5, 1, -2, -1, 0, 0, -1, -2, 2], [-4, 3, 5, 4, 2, 3, -4, -1, 6, 1], [16, 2, -5, -1, 0, -1, -4, -5, -3, -2], [4, 7, 5, 6, 1, 2, 0, 2, 0, 2], [5, -9, -1, 1, -3, -3, 1, -5, -1, 3], [15, 3, 2, -1, 6, 5, 5, 9, 3, -3], [12, 0, -5, 7, 1, 2, -1, -3, 1, -1], [10, 0, -3, 2, 0, -1, 5, 0, 2, 1], [2, -4, 9, 4, 0, 3, 1, 0, 0, 3], [0, 11, -5, 2, 0, 1, -8, -2, -4, -3], [-10, -2, 6, 7, 5, 3, 3, 5, 5, 6], [-1, 4, -2, 2, 3, -2, 2, -1, 0, -1], [-5, -4, -1, -3, -4, 0, 2, -3, -5, -2], [0, -3, 0, 2, 0, 2, -1, -1, 2, 2], [11, 0, 8, 0, 1, 1, 3, 3, 2, -2], [-15, 0, -6, 9, 0, 2, -2, -2, 0, -2], [-4, 0, -5, 8, 1, 4, -4, -2, 2, 2], [-2, 11, -3, -9, 1, 3, -2, 6, -5, -6], [11, -2, 6, 1, -4, -5, 3, 3, -1, 5], [2, 3, -6, 2, -2, 0, -7, -7, 0, -2], [11, 7, 4, -2, 4, 5, 1, 9, -2, -6], [-1, 2, -8, -7, -2, -1, 3, -2, -7, -3], [-4, 2, 2, -3, -3, -1, 5, 5, -5, -4], [16, -2, -8, -1, -1, -1, -3, -1, -3, -2], [-5, 0, 7, -2, -2, -3, 2, -3, 3, 4], [-14, -2, 0, -10, -1, -7, 4, 1, -4, 3], [10, 6, -4, -4, -2, -1, -5, 3, 0, -5], [3, 3, 8, 5, 6, 0, 3, 2, 2, 0], [-5, 1, 2, -5, 0, -1, 0, 6, 1, 1], [-10, 4, -6, 3, -3, -1, 0, -3, -1, -2], [1, -3, -2, 0, 1, 0, -6, -5, 4, 1], [6, 1, 3, 1, -1, -2, 3, 0, 1, 3], [-3, 0, -8, -6, -4, -1, 4, -4, -2, 0], [-4, 6, 1, -4, 0, 4, -2, 5, -7, -6], [19, -1, -1, 0, -1, 2, -3, -1, 2, -5], [0, 2, 6, 0, -1, 1, -6, 0, -2, 3], [1, 6, -9, -12, 0, -1, 1, -1, -5, -2], [-11, 9, -5, -7, -3, -1, 1, -1, -1, -3], [4, -5, 5, 7, 3, 0, 1, 1, 3, 1], [12, -3, -2, -9, -11, -4, -3, -6, -2, -1], [-7, 1, -10, 2, -5, -4, -6, -6, -4, -3], [-4, 2, -1, -6, 4, 4, -4, -3, -3, 0], [-4, 2, 4, -4, -1, 3, 0, 0, 0, -3], [-9, 1, -3, 4, -2, -2, 0, -1, -6, 1], [-2, 1, -2, 0, -4, 0, -1, -6, -4, -2], [-7, 2, 1, 1, 0, -1, -2, 4, 0, -3], [-6, -5, 3, -3, -2, 1, 0, -1, -1, -2], [10, 0, 8, 2, -2, 0, 2, 6, 4, -2], [-1, -2, -2, -5, 1, -6, -3, -1, 1, 0], [3, -6, -3, 4, -7, 0, 2, -3, -2, -1], [4, -4, 2, 0, -1, 1, -2, -1, 6, 1], [-14, -5, -4, -6, 4, 1, 0, -1, -1, -1], [-12, 1, 0, 5, 6, 4, -2, 3, 3, 1], [10, 2, 1, 3, 4, 7, -2, 1, 1, -6], [13, 3, -4, -2, -1, -2, -1, 0, 6, 1], [-7, -3, 4, 4, 3, 3, -2, -3, 2, 2], [-4, 2, 4, 3, -7, 1, -6, -1, 3, 0], [-3, -3, -7, -10, -4, -6, -4, -6, -4, -1], [3, -3, -1, 1, 2, 5, -1, 8, 0, -1], [-1, 4, -1, -2, -3, -3, 1, -4, 0, 0], [0, -7, 3, -1, 1, 2, 0, 1, 3, 1], [11, 3, -5, -5, 0, 2, 3, -1, 1, -4], [-22, 8, -7, -2, -3, 3, -4, -1, -4, -5], [11, 3, 2, -2, 4, -2, 2, 1, -3, -1], [-4, -10, -4, 0, -6, 0, -4, -2, -4, -2], [-8, -6, -6, -8, -10, -6, -6, -9, -2, 2], [-7, -3, 5, -2, 4, 4, 2, 8, 2, -1], [-1, 0, -12, -8, 1, -3, 2, -5, -5, 0], [15, -3, 3, 1, -1, -3, 5, 5, 1, 5], [-7, -6, 5, 4, -3, -1, 3, 1, 0, 2], [3, -1, -2, -8, 1, -4, 3, 8, -2, -3], [0, 9, -9, -3, -3, -2, -4, -3, 1, -1], [2, -5, 4, 4, -4, 2, -3, -5, 4, 6], [-5, -9, 3, 7, 5, -1, 3, -3, 1, 1], [-7, 10, -2, -7, -1, -4, -2, -3, -5, 2], [-25, -3, 2, 0, 3, 2, 1, 5, -2, -1], [-5, -3, 8, 0, 3, -2, 9, 6, -2, -1], [13, -8, -2, 3, 2, 1, -3, 1, 1, -1], [-12, 8, 1, -13, -4, -5, -2, -1, 1, 2], [-17, 4, 4, -4, 2, 3, 2, 2, -4, 0], [3, 0, -3, -9, -7, -7, -9, -8, -5, 3], [10, 5, -2, -6, -6, -5, -4, -8, -8, 1], [3, -3, 3, 5, 6, 2, 3, 0, -1, 0], [0, 5, 6, 6, 5, 3, -9, 4, 6, 1], [-2, 2, 0, 0, 0, 8, -6, -2, -2, -4], [-16, -4, 2, -4, -3, 2, -2, -3, 3, 2], [-3, 3, -3, -1, 6, -3, 2, 2, 2, 1], [7, 5, -5, 3, -3, -3, -11, -9, -3, 3], [-8, 0, -6, -3, -7, -11, 2, -3, -5, 0], [-12, 2, 2, -7, -5, -2, -4, -4, 3, 3], [-5, -10, -2, 6, -3, -6, 0, -10, -2, 3], [-7, 0, 6, 4, -5, -2, -2, 0, 0, 1], [-5, 3, 4, 4, 4, -1, 1, 1, 4, 0], [0, 5, 1, 9, 2, -4, 7, 4, -2, 1], [0, 1, -2, 8, -7, 2, -9, -5, 1, 2], [-8, 1, 6, -6, 5, -1, 8, 6, 6, -1], [-1, 5, -2, -10, -9, -5, -2, -3, 0, 0], [6, 0, -2, -3, 3, 1, -3, 0, 1, 2], [-18, -5, -11, 1, -2, 0, -2, -4, -9, 1], [3, 0, -1, 8, 3, 4, 3, -3, 5, -1], [1, 6, 0, -8, 3, 2, 4, 12, -2, -7], [-3, -10, 7, 7, -5, 2, -7, -4, 6, 6], [1, -5, -4, 5, -4, 0, 2, -4, 0, 8], [4, -4, 1, -2, 3, -1, 0, 3, 2, 3], [-7, 0, -10, 4, -6, -2, -6, -9, -3, 7], [13, -5, 1, 9, 0, 5, 2, -2, -1, -3], [-9, -7, -2, 8, -5, -1, 3, -5, 1, 4], [-27, 9, -2, 6, 1, 3, -2, 1, 0, -2], [-12, 4, -3, -6, -3, -2, -7, -4, -4, -4], [27, -7, 1, 1, -7, -2, 1, -2, 0, 4], [-5, -3, 4, -7, 2, -5, 10, -1, -3, 5], [12, -5, -1, 6, -1, -1, -5, -3, 5, -1], [-8, 11, -6, -3, 2, -4, 2, 5, -1, -3], [1, 3, 3, 3, 4, 5, 5, 2, 2, -5], [3, -2, -1, 8, -5, 0, -2, -5, -2, 9], [-8, 10, -6, 3, 8, -2, 3, 9, 3, -3], [34, 5, 3, 0, 2, 3, 4, 2, 6, 1], [-26, 4, 2, 0, 0, 2, -4, 4, 0, -6], [10, 1, -9, -4, 0, 6, -7, 1, -4, -4], [-1, -5, 6, 9, 7, -2, 5, 3, 1, 4], [-9, -5, 0, 3, 0, -3, 5, -3, 3, 5], [0, -2, -3, -5, -3, -6, 0, 3, -1, -7], [6, -1, 1, 10, 5, 3, 1, -5, 2, 5], [7, 0, 6, 7, 1, 5, 1, 0, 6, 5], [0, 8, 0, -7, 2, -4, -1, -1, -3, -9], [-1, 0, -2, 2, -9, -4, -2, -12, 2, 3], [-7, -10, -1, -6, -1, 1, -5, 2, -6, 0], [-20, 7, -2, -1, -2, 4, 0, -4, -1, -3], [3, 10, 5, -4, 0, 1, 1, 1, -1, -4], [8, 18, -7, -9, 3, 0, -4, 1, -3, -9], [-13, -8, 9, 2, -3, 0, -4, -1, -3, 3], [5, -3, 8, -5, -2, 3, 4, 7, -1, -1], [-8, -9, 4, 16, 1, 0, 4, -5, 1, 10], [4, -2, 11, 5, 7, 3, 1, 5, 7, 0], [-2, -7, 6, -2, -8, -2, -2, -10, -4, 4], [0, -2, 2, 3, -3, 5, 3, -1, -1, 0], [-19, 2, 4, 5, 2, 2, 0, 2, 4, 2], [-20, 8, -4, 1, 6, 1, -6, 0, 0, -4], [33, 3, 2, 3, -1, 1, -3, -2, 3, -3], [3, 7, 6, -5, -1, 2, 6, 3, 1, 4], [-4, 4, -6, -1, 2, 0, 2, 0, -1, 1], [-9, -1, -4, -2, -6, -6, -4, -3, 2, 3], [4, 6, 9, 8, 11, 2, 5, 0, 6, 6], [-2, 8, 2, -2, 10, 9, 2, 17, -1, -11], [-3, -3, -14, -2, -9, -4, -6, -6, 2, -1], [4, -4, 3, -2, 2, 1, -1, 5, 0, -5], [5, 6, -8, -9, -2, -7, -5, -5, -5, -9], [12, 1, 0, -6, -1, -3, -3, 0, -6, -1], [-7, -1, 5, 2, 3, 2, 1, 7, 10, 1], [0, -7, 4, 10, 4, 4, 2, 1, 4, -2], [9, -8, 9, 1, 8, 0, 10, 7, 5, -2], [-5, -1, 8, 7, 9, 4, 4, 1, 1, 0], [-26, 8, 2, 3, 4, 4, -1, 3, -3, -1], [-4, 1, 4, 5, 7, -1, 4, 9, 7, 0], [-2, -2, -5, 0, 0, 2, -5, 5, -1, -6], [4, 2, -11, -5, 4, -1, -3, 5, -1, -8], [7, -1, -12, 4, -1, -4, 3, -1, -4, -3], [-20, -4, -10, -5, -7, -7, 0, -8, -3, 2], [-3, -5, 1, 7, 2, 2, -5, -5, 5, 6], [0, -14, 5, 2, -5, -4, 5, -6, 2, 6], [11, -4, 1, 4, -3, 0, -6, -3, 0, 3], [14, 10, 4, -8, -2, -2, 9, 8, -2, 0], [31, -6, 8, 18, 2, 6, -4, -3, 5, 5], [-19, 1, 6, -6, -1, 4, -7, 2, 0, 1], [15, -6, -1, 9, 0, 4, 0, -8, -5, 0], [19, -10, 7, 0, -4, -3, -2, -7, 6, 6], [-11, 0, -7, -1, -8, -2, 0, -9, -1, 0], [-19, -4, 5, 2, 6, 4, -1, 8, 4, -1], [-9, -8, 1, 5, 0, -2, 2, 0, 7, 6], [13, 5, 2, 3, 7, 3, 7, 6, -2, 1], [12, -4, -5, 3, 2, -1, -2, 7, -5, -2], [-7, 6, 4, 3, 12, 8, 3, 18, 4, -12], [-13, 14, -4, -11, 1, 2, 3, 4, -11, -2], [1, -4, -1, -11, 0, 0, 4, 3, -1, -2], [10, 0, 8, 7, 6, 3, 8, 14, 11, -4], [4, 0, 11, -2, 3, 6, -1, 4, 2, 2], [-4, -6, 11, 2, 4, -3, 4, 6, 8, -3], [12, 2, -9, -4, -7, -4, -7, -10, 2, 8], [-1, -6, -2, 3, 0, 1, 5, 4, 1, 3], [-13, -5, 9, 5, -9, -3, -3, -7, 3, 11], [15, -10, 8, -4, 0, -1, 4, 4, 4, 10], [4, -7, -5, 17, 5, 6, 2, 3, 5, -1], [-6, -2, 12, 14, 0, 2, -4, -2, 10, 2], [15, 3, -1, -1, 8, 5, 3, -8, 2, 3], [24, -9, -5, -6, -5, -2, 5, 4, 0, 6], [1, -10, 16, 9, 7, 2, 6, 7, 9, 4], [-2, -4, 11, 6, 9, 4, 7, -2, 6, 2], [-2, 9, -7, -1, -5, -10, -3, -7, -1, -1], [12, -2, -9, -9, -12, -1, -5, -6, -5, -6], [-12, 3, -9, 8, -3, -4, -4, -8, -2, -2], [8, -10, -3, -18, -9, -5, -6, -5, -8, -1], [5, -4, 0, -2, -8, -3, -9, -12, 0, 2], [-28, 5, 6, -5, 1, -5, -2, 0, -1, 8], [17, 4, 6, 5, 6, 7, 11, 9, 3, -9], [-7, 4, -8, 1, -1, 0, 7, -3, 1, 2], [-17, -6, 4, 0, -3, 2, -8, -6, 0, -1], [-1, -4, -3, -3, -2, -5, 0, 0, 0, -5], [3, 0, 3, 3, 4, 8, 8, 3, -1, 2], [6, -2, -15, 0, -3, -2, -3, -6, -14, -2], [1, -2, 4, 5, 4, 3, -1, 5, 5, -5], [-12, -8, -5, 0, -5, -2, 1, -2, -2, 6], [8, 4, -1, -1, 2, 3, -2, 5, 1, -2], [5, -10, 3, 5, -3, -9, -4, -6, 3, 11], [-13, -7, 4, 4, 6, -2, -2, 1, -3, -1], [-17, -5, -6, -6, -6, -7, 6, -6, 0, 6], [-8, 11, -2, -4, 7, 7, -1, 7, -4, -5], [16, 4, 9, 12, 3, 6, -4, -2, 2, -4], [12, 2, 18, -2, 12, 2, 10, 8, 12, 0], [0, -2, 15, 10, 6, 7, 1, 8, 4, -7], [-8, 6, -12, -17, -15, -8, -6, -4, -7, -7], [-2, 2, -2, 11, 9, 7, -1, 5, -1, -10], [-8, 5, 2, 13, 1, 3, -4, -12, 7, 6], [-20, 3, -1, -2, 8, -4, -3, -3, -8, -2], [11, 15, -6, -7, 1, -2, -4, -7, -7, -2], [-15, 5, -4, -11, 5, 0, -2, -5, 1, -4], [18, 4, -4, -9, -3, -4, -6, -7, -1, 1], [-10, 5, 1, -1, 0, 8, -10, 6, 0, -5], [2, -2, -3, -1, -4, 3, -7, 0, -1, -4], [-6, 3, 1, -4, 7, 0, 16, 6, 2, -4], [15, 12, -11, -14, -3, -3, -5, 0, -4, -10], [-7, 2, 0, -6, -6, 1, -5, 4, 0, -8], [8, -1, -9, -7, -13, -4, -11, -9, -3, 1], [-25, -1, -4, -3, -1, 11, -1, 12, 0, -9], [19, 7, 1, -5, -5, -4, -4, 0, 4, -4], [-7, 10, 11, 9, 10, 12, 2, 13, 7, -6], [-1, -5, 3, -2, 11, 1, 4, 6, 2, -4], [-3, 2, -3, -13, -4, -6, -3, -12, -5, -4], [7, -13, 8, 15, 0, 1, -3, 1, 11, 5], [0, -6, -14, 1, -6, 0, 3, -3, -7, -1], [9, 1, 2, 9, 1, 0, 6, -3, 5, 4], [-16, 1, -1, -3, 1, 0, 3, -1, -1, 1], [-4, -4, -8, 6, 5, -1, 0, -6, 2, 5], [-2, 3, -12, -12, 0, 3, -2, -7, -10, 1], [-8, -6, -16, -9, -2, 0, 0, 0, -7, -1], [-13, -8, 0, 4, -1, -6, 1, -6, -4, 9], [-5, -2, 0, 2, -2, -4, 3, -1, 6, 1], [3, 7, 3, 4, -6, 5, -6, 3, 3, -2], [-13, 5, -11, -13, 1, 3, -5, -9, -9, 1], [11, -20, 13, 3, -1, 0, 3, 1, -3, 8], [1, -4, -6, 4, -4, 5, -12, -10, -2, 4], [13, 8, 0, 4, 0, -4, 5, 3, -3, -5], [31, -1, 3, -7, -4, 0, -1, -3, -1, 4], [19, -11, 8, 17, 3, 7, 5, 6, 9, 7], [-11, 0, -15, -2, 1, -1, 1, -4, -2, 2], [-24, -1, 7, 3, -5, 0, -7, -3, -1, 7], [-9, 0, 2, 6, 3, 1, -3, -1, 1, 2], [17, -7, 7, -2, -2, -3, 0, 5, 1, 4], [28, 0, 8, -6, 0, 5, 4, 9, 3, -7], [-15, 3, -11, -3, -8, 1, -8, -2, -2, -3], [5, -9, -1, -3, -1, -5, 7, 0, -3, 1], [-24, 4, -5, 9, 2, -1, -8, -6, 1, -2], [-7, 4, -2, -4, -2, -3, 4, 2, -4, 0], [41, 5, -2, -5, -2, -3, -4, 6, 1, -5], [26, -1, -7, -11, -8, -9, -5, 0, -9, 0], [6, 2, 10, 10, 14, 6, 9, 12, 8, 2], [0, -7, -3, 1, 6, -6, -2, -5, 3, 3], [-7, 6, -7, -12, -2, 5, -4, -1, -3, -10], [39, 14, -4, -13, 1, 0, -1, 4, -1, 0], [-25, 3, 4, 3, -8, -1, -2, -9, 1, 5], [-13, -11, 8, -2, 1, -6, 5, 9, 6, 9], [9, 6, -1, -10, 0, 0, 9, 12, 0, -5], [10, -11, 11, 15, 2, 7, -3, 3, 9, 2], [-23, -4, -12, -10, -3, -8, 0, -1, -10, 3], [-11, -12, 9, 12, 0, 2, 1, 0, 14, 7], [-12, 4, -4, 5, -4, -5, -4, -6, -1, 4], [16, -14, 1, -7, -2, 0, -5, 0, 0, -5], [45, 0, 4, 10, 6, 4, -1, 2, 8, 5], [4, -7, 8, -5, 4, -6, 12, 7, 1, 5], [4, -6, -1, -5, -10, -13, -8, -11, -5, 10], [51, -8, -2, -5, -3, -5, 0, 0, 1, 5], [16, 0, 1, 9, 0, 3, 4, 7, -7, 0], [-12, 12, -16, 4, -2, 0, -12, -16, -2, 6], [-9, -13, -1, -8, -5, -1, -2, 7, -4, -6], [-1, -10, -3, 0, -2, -1, -9, -5, 1, 6], [-5, -2, 10, 2, 6, 4, -5, -1, -5, 3], [-17, -2, -5, 3, -6, -1, -7, -5, -7, 5], [0, 5, 6, 3, 10, 6, 4, 3, 1, -3], [-9, -13, 4, 11, 9, 5, 5, -4, 3, 3], [0, 10, 9, 1, 6, 4, 0, 8, 2, -3], [11, 0, -1, 14, 9, 7, 0, 2, 2, 2], [-11, 1, -13, -11, 1, -8, 1, 0, -4, 2], [1, 1, 14, 0, -2, -3, 5, -2, -6, 8], [16, 12, -6, -11, 1, 9, -7, 7, -3, -18], [14, 14, -2, -4, 5, 6, -1, 1, 0, -2], [7, 3, 7, 1, 7, 5, -1, -2, -1, -1], [11, -9, 4, 12, 6, 5, 2, 3, 6, 10], [4, 3, -8, 2, 2, 3, 6, -1, 4, -1], [-6, 18, 2, 3, 6, 2, -3, 2, -5, -1], [1, 10, 7, 8, -1, -2, 4, -2, -2, -1], [-13, -15, 10, 10, -5, 4, -4, -4, 6, 5], [12, -1, 13, 2, -1, -2, -2, 9, 0, 2], [2, 8, -5, 3, -2, -1, -9, 1, -3, -6], [-6, 17, -1, 0, 8, 11, -2, 6, -4, -5], [37, -3, -4, 10, 0, -5, -4, -13, 0, 6], [18, -17, 7, 8, 0, 3, 0, 0, 8, 3], [9, 7, -18, 2, 6, 6, 0, 1, 1, -5], [-3, 12, -7, -4, -2, -4, -2, -2, -6, -5], [-3, -5, 0, 11, 0, -3, -6, -3, 5, 5], [-20, 0, 7, 1, 2, 5, 12, 11, 1, 0], [24, -2, -10, -4, -3, -2, -8, 1, 1, -6], [9, -16, 6, -7, -4, -7, 7, -3, -1, 3], [-2, -3, 4, -3, 1, 0, -5, -6, 3, -1], [17, -3, -13, -7, -2, 4, -5, -3, 3, -10], [13, -2, -3, 10, 0, 0, 6, 6, 6, 1]]
